import React from 'react';
import Fuse from 'fuse.js';
import { ButtonProps } from '@mui/material';
/**
 * List item height preset values
 */
export declare enum ItemHeightPreset {
    SMALL = 24,
    MEDIUM = 32,
    LARGE = 40,
    XLARGE = 48
}
/**
 * Type that describes the height of each search / recent list item
 */
export type ItemHeight = ItemHeightPreset | number;
/**
 * Type that every item passed into the `items` prop must extend
 */
export type SearchItemRequirements = {
    label: string;
} | string;
/**
 * Arguments passed into the `renderResult` and `renderRecent` functions
 */
export type RenderItemArgs<T> = {
    item: T;
    smallDisplay: boolean;
    closeDialog: () => void;
    addToRecents: () => void;
};
export type SearchProps<T> = {
    /**
     * List of items to search through.
     *
     * **NOTE: Each item must have a `label` property or be a string!**
     *
     * This constraint is enforced for two main reasons:
     * 1. So that the search engine has a property it can depend on being present to
     * use when searching
     * 2. When using the default `renderResult` function, it can assume that is the
     * item isn't a string, that is can use the `label` property to display the item
     * @see SearchItemRequirements
     */
    items: T[];
    /**
     * Props passed to the search button that opens main search dialog
     * @see ButtonProps
     * @link https://mui.com/api/button/
     */
    buttonProps?: ButtonProps | ((isSmallScreen: boolean) => ButtonProps);
    /**
     * Search engine options passed to Fuse.js.
     *
     * **NOTE: `label` is preserved as an attribute in the search key array.**
     */
    fuseOptions?: Fuse.IFuseOptions<T>;
    /**
     * Place holder displayed in the search input when empty
     * @default 'Search'
     */
    placeholder?: string;
    /**
     * Title for the Quick Fill section of the search dialog
     * @default 'Quick Fill'
     */
    quickFillTitle?: string;
    /**
     * Height of each search result item
     * @default ItemHeightPreset.LARGE
     * @see ItemHeight
     */
    itemHeight?: ItemHeight;
    /**
     * List of items to display in the quick fill section of the search dialog
     */
    quickFillItems?: T[];
    /**
     * Maximum height of the search dialog
     */
    maxHeight?: React.CSSProperties['maxHeight'];
    /**
     * Maximum width of the search dialog
     */
    maxWidth?: React.CSSProperties['maxWidth'];
    /**
     * Whether or not to show recent searches
     */
    noHistory?: boolean;
    /**
     * Callback function that is called when a search result item is selected
     *
     * **NOTE: If not using `renderResult`, this prop is required! If using `renderResult`,
     * this prop does nothing.**
     * @param item The item that was selected
     */
    onItemSelect?: (item: T) => void;
    /**
     * Function that renders each search result item
     * @param result The item to render
     * @param smallDisplay Whether or not the search dialog is in small display mode
     * @param closeDialog Function to call to close the search dialog
     * @param addToRecents Callback function that should be called when the item is selected
     * @returns JSX.Element
     */
    renderResult?: ({ item, smallDisplay, closeDialog, addToRecents, }: RenderItemArgs<T>) => JSX.Element;
    /**
     * Function that renders each recent search item
     * @param recent The item to render
     * @param smallDisplay Whether or not the search dialog is in small display mode
     * @param closeDialog Function to call to close the search dialog
     * @param addToRecents Callback function that should be called when the item is selected
     * @returns JSX.Element
     */
    renderRecent?: ({ item, smallDisplay, closeDialog, addToRecents, }: RenderItemArgs<T>) => JSX.Element;
};
/**
 * All in one search dialog component!
 *
 * **Required props:**
 * - `items` - List of items to search through. Each item must have a `label` property or be a string
 * - `onItemSelect` - Callback function that is fired when a search result item is selected
 *
 * **Conditionally required props:**
 * - `onItemSelect` - Required if not using `renderResult` prop. Prop is required in this case so that
 * each search result item has an onClick handler
 *
 * **Recommended optional props:**
 * - `renderResult` - Function that renders each search result item
 * - `renderRecent` - Function that renders each recent search item
 * - `quickFillItems` - List of items to display in the quick fill section of the search dialog
 * - `itemHeight` - Height of each search result / recent search item
 *
 * @see SearchProps
 * @returns JSX.Element
 */
export declare const Search: <T extends SearchItemRequirements>({ items, buttonProps, fuseOptions, placeholder, quickFillTitle, itemHeight, quickFillItems, maxHeight, maxWidth, noHistory, onItemSelect, renderResult, renderRecent, }: SearchProps<T>) => JSX.Element;
